### 0.2
*2019-11-17*

**Feature**

*MSFT-1238 Token authentication*

- Update authentication docs. [Artur Barseghyan]
- Implement token authentication. [Artur Barseghyan]

*MSFT-1237 Improve document sharing*

- Improve document sharing. Add option to share via GDrive. [Artur Barseghyan]

### 0.1
*2019-11-17*

**Bugfix**

*MSFT-1236 Prevent duplicate postal codes*

- Make postal code field unique for the country. [Artur Barseghyan]
- Normalise postal codes for US addresses. [Artur Barseghyan]
- Normalise postal codes for German addresses. [Artur Barseghyan]

**Deprecation**

*MSFT-1235 Deprecate old api*

- Update docs. [Artur Barseghyan]
- Deprecate API v 2.0. [Artur Barseghyan]

**Feature**

*MSFT-1234 Car type suggester*

- Add insurance amount indication based on car weight. [Artur Barseghyan]
- Initial car type suggester implementation. [Artur Barseghyan]
